<?php
/**
 * Plugin Name: WooCommerce Downloadable Checkout-Popup (EasyToolsWP)
 * Description: Automatically shows a popup with download links after order completion and adds a button to reopen the popup.
 * Version: 1.7
 * Author: EasyToolsWP.com
 */

defined('ABSPATH') || exit;

// Hook for displaying popup after order completion
add_action('woocommerce_thankyou', 'wdp_show_download_popup', 20);

function wdp_show_download_popup($order_id) {
    // Get order object
    $order = wc_get_order($order_id);

    if (!$order) {
        return;
    }

    // Check if there are downloadable items
    $downloads = array();
    foreach ($order->get_items() as $item_id => $item) {
        if ($item->is_type('line_item')) {
            $product = $item->get_product();
            if ($product && $product->is_downloadable()) {
                foreach ($product->get_downloads() as $download_id => $download) {
                    $downloads[] = array(
                        'name' => $download['name'],
                        'url' => $download['file'],
                        'remaining' => $item->get_meta('wc_downloads_remaining') ?: 'Unlimited',
                        'expires' => $item->get_meta('wc_download_expiry') ?: 'Never'
                    );
                }
            }
        }
    }

    if (empty($downloads)) {
        return;
    }

    // Store download data in a global variable for use in footer
    global $wdpPopupData;
    $wdpPopupData = $downloads;

    // Add inline script and styles for the popup
    add_action('wp_footer', 'wdp_add_popup_assets');
}

function wdp_add_popup_assets() {
    global $wdpPopupData;

    if (empty($wdpPopupData)) {
        return;
    }

    ?>
    <style>
        .wdp-popup {
            display: none;
            position: fixed;
            left: 0;
            top: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.5);
            z-index: 9999;
            overflow: auto;
        }
        .wdp-popup-content {
            background: #fff;
            margin: 5% auto; /* Adjusted for better centering */
            padding: 20px;
            width: 90%;
            max-width: 600px; /* Increased max-width for more space */
            position: relative;
            box-shadow: 0 2px 15px rgba(0, 0, 0, 0.2);
            border-radius: 8px;
        }
        .wdp-popup-close {
            position: absolute;
            top: 10px;
            right: 10px;
            font-size: 24px;
            cursor: pointer;
            color: #333;
        }
        .wdp-popup h2 {
            margin-top: 0;
            font-size: 24px;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
        }
        .wdp-popup ul {
            list-style: none;
            padding: 0;
            margin: 0;
        }
        .wdp-popup li {
            padding: 10px 0;
            border-bottom: 1px solid #eee;
            display: flex;
            flex-direction: column;
        }
        .wdp-popup li:last-child {
            border-bottom: none;
        }
        .wdp-download-name {
            font-weight: bold;
            margin-bottom: 5px;
        }
        .wdp-download-info {
            color: #555;
        }
        .wdp-download-link {
            display: block;
			float:right!important;
			width:180px;
            margin-top: 10px;
            padding: 8px 12px;
            background: #0073aa;
            color: #fff;
            text-decoration: none;
            border-radius: 4px;
            text-align: center;
        }
        .wdp-download-link:hover {
            background: #005177;
			color:#fff;
        }
		.wdp-linkurl{
            font-size:0.8em;
			color:#666;
        }
    </style>
    <script>
        jQuery(document).ready(function($) {
            // Pass download data to JavaScript
            window.wdpPopupData = <?php echo json_encode($wdpPopupData); ?>;

            // Show the popup on page load if downloads exist
            if (typeof wdpPopupData !== 'undefined' && wdpPopupData.length > 0) {
                $('#wdp-popup').show();
            }

            // Close popup button click event
            $('#wdp-popup .wdp-popup-close').on('click', function() {
                $('#wdp-popup').hide();
            });
        });
    </script>
    <div id="wdp-popup" class="wdp-popup">
        <div class="wdp-popup-content">
            <span class="wdp-popup-close">&times;</span>
            <h2>Your Downloads</h2>
            <ul>
                <?php foreach ($wdpPopupData as $download): ?>
                    <li>
                        <span class="wdp-download-name"><?php echo esc_html($download['name']); ?></span>
                        <span class="wdp-download-info">Remaining: <?php echo esc_html($download['remaining']); ?></span>
                        <span class="wdp-download-info">Expires: <?php echo esc_html($download['expires']); ?></span>
                        <a href="<?php echo esc_url($download['url']); ?>" target="_blank" class="wdp-download-link">Download now</a>
						<a href="<?php echo esc_url($download['url']); ?>" target="_blank" class="wdp-linkurl"><?php echo esc_url($download['url']); ?></a>
                    </li>
                <?php endforeach; ?>
            </ul>
        </div>
    </div>
    <?php
}
